@@ -1,4 +1,4 @@
-### ggm.estimate.pcor  (2004-01-15)
+### ggm.estimate.pcor  (2004-03-15)
 ###
 ###     Various small-samples estimators of GGM partial correlation coefficients
 ###
@@ -32,7 +32,7 @@ ggm.estimate.pcor <- function(x, method=c("observed.pcor",
   
   if (method == "observed.pcor")
   {
-    return( pcor(x, ...) )
+    return( partial.cor(x, ...) )
   } 
 
   ########
